
.. include:: ../README.rst
   :end-before:  Installation

.. toctree::
   :hidden:
   :maxdepth: 1

   source/installation
   source/demo
   source/examples
   source/conversions
   source/api
   source/info

`API Reference <source/api.html>`_
------------------------------------------------

Documentation for the functions included in Scilab2Py.

`Installation <source/installation.html>`_
------------------------------------------------

How to install Scilab2Py.


`Examples <source/examples.html>`_
------------------------------------------------

Introductory examples.


`Type Conversions <source/conversions.html>`_
------------------------------------------------

Scilab2Py data type conversions.


`Information <source/info.html>`_
-----------------------------------------

Other information about Scilab2Py.
